@@ -2,10 +2,16 @@ class CommandCapsule:
     def __init__(self, command_application):
         self.command_application = command_application
         self.commands = []
+        self.command_name = []
 
     def add(self, *commands):
-        self.commands.append(commands)
-        self.command_application.add_commands(*commands)
+        for command in commands:
+            command_name = command.config.name
+            if command_name in self.command_name:
+                continue
+            self.command_name.append(command_name)
+            self.commands.append(command)
+            self.command_application.add_commands(command)
         return self
 
     def swap(self, command):
