@@ -1,6 +1,4 @@
-"""Down Command."""
-
-from cleo import Command
+from .Command import Command
 
 
 class DownCommand(Command):
@@ -11,5 +9,7 @@ class DownCommand(Command):
     """
 
     def handle(self):
-        with open("bootstrap/down", "w+"):
+        with open(".down", "w+"):
             pass
+
+        self.info("Server is down for maintenance !")
